@@ -267,8 +267,30 @@ static int xfs_quota_get(quota_t *myquota) {
    block_diff = BLOCK_SIZE / 512;
    retval = quotactl(QCMD(Q_XGETQUOTA, myquota->_id_type), myquota->_qfile,
 		     myquota->_id, (caddr_t) &sysquota);
+   /* 
+      ** 2005-04-26  : fmicaux@actilis.net -
+                        handling a non-set quota for a user/group
+                                             who owns nothing here
+   */
    if ( retval < 0 ) {
-      output_error ("Failed fetching quotas: %s", strerror(errno));
+      // This error has to be explained :
+      // if UID/GID has no quota defined, and owns no data, ENOENT error occures
+      // but at this point of the code, whe know that this XFS has quotas.
+      // We make the choice to produce a "0 0 0 0 0 0 0 0" line.
+      if ( errno == ENOENT ) {
+         myquota->block_hard	= 0;
+         myquota->block_soft	= 0;
+         myquota->block_used	= 0;
+         myquota->inode_hard    = 0;
+         myquota->inode_soft    = 0;
+         myquota->inode_used    = 0;
+         myquota->block_grace	= 0;
+         myquota->inode_grace	= 0;
+         myquota->block_time	= 0;
+         myquota->inode_time	= 0;
+         return 1;
+      }
+      output_error ("Failed fetching quotas: errno=%d, %s", errno, strerror(errno));
       return 0;
    }
 
